@@ -457,18 +457,23 @@ class zetldbaccess:
 				except Exception as e:
 					raise Exception('Cannot create table ' + tablename + '\n' + str(e))
 					
-	def export_zetl(self):
-		
-		etl_list = self.db.query('SELECT DISTINCT etl_name FROM ' + self.db.db_conn_dets.DB_SCHEMA + '.z_etl ORDER BY etl_name')
+	def export_zetl(self,etl_name =''):
+		zsql = ' SELECT DISTINCT etl_name FROM ' + self.db.db_conn_dets.DB_SCHEMA + '.z_etl '
+		if etl_name != '':
+			zsql += "WHERE upper(etl_name) like upper('" + etl_name + "') "
+		zsql += ' ORDER BY etl_name '
+		etl_list = self.db.query()
 		for etl in etl_list:
 			etl_name = etl[0]
 			qry = "SELECT stepnum,cmdfile,steptablename,estrowcount FROM " + self.db.db_conn_dets.DB_SCHEMA + ".z_etl WHERE etl_name = '" + etl_name + "' ORDER BY stepnum"
 			csv_filename = 'zetl_scripts\\' + etl_name + '\\z_etl.csv'
 			self.db.export_query_to_csv(qry,csv_filename)
 
-	def empty_zetl(self):
+	def empty_zetl(self,etl_name=''):
 		try:
 			dsql = "DELETE FROM " + self.db.db_conn_dets.DB_SCHEMA + ".z_etl "
+			if etl_name != '':
+				dsql += " WHERE upper(etl_name) like upper('" + etl_name + "') "
 			self.db.execute(dsql)
 			self.db.commit()
 		except:
